==> haskell-text-rope-0.3-90-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-27VJjUs35g78EaA2UXN6ds
key:                  text-rope-0.3-27VJjUs35g78EaA2UXN6ds
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  0e1e6023731ac40811a2716f75d67305
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-27VJjUs35g78EaA2UXN6ds
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-ALyKXv7XVpOIl9EVBdgwIc

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-text-rope-0.3-91-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-text-rope.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 text-rope
version:              0.3
visibility:           public
id:                   text-rope-0.3-AVNxYLyPV9vJ7y5KneRoBV
key:                  text-rope-0.3-AVNxYLyPV9vJ7y5KneRoBV
license:              BSD-3-Clause
copyright:            2021-2022 Andrew Lelechenko, 2024 Olle Fredriksson
maintainer:           Andrew Lelechenko <andrew.lelechenko@gmail.com>
author:
    Andrew Lelechenko <andrew.lelechenko@gmail.com>, Olle Fredriksson <fredriksson.olle@gmail.com>

homepage:             https://github.com/Bodigrim/text-rope
synopsis:             Text lines and ropes
description:
    A wrapper around `Text` for fast line/column navigation and logarithmic concatenation.

category:             Text
abi:                  ac50ebcbab5d47436fc41908ea7d0f96
exposed:              True
exposed-modules:
    Data.Text.Lines Data.Text.Mixed.Rope Data.Text.Rope
    Data.Text.Utf16.Lines Data.Text.Utf16.Rope
    Data.Text.Utf16.Rope.Mixed Data.Text.Utf8.Lines Data.Text.Utf8.Rope

hidden-modules:       Data.Text.Lines.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/text-rope-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-text-rope
hs-libraries:         HStext-rope-0.3-AVNxYLyPV9vJ7y5KneRoBV
depends:
    base-4.17.2.1 deepseq-1.4.8.0 text-2.0.2
    vector-0.13.2.0-EQFZws9ZIK8A2ESM3MR23n

haddock-interfaces:   /usr/share/doc/haskell-text-rope/html/text-rope.haddock
haddock-html:         /usr/share/doc/haskell-text-rope/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
